@@ -12,6 +12,9 @@ require_relative 'diff'
 begin
   require 'power_assert'
 rescue LoadError, SyntaxError
+  if defined?(::PowerAssert)
+    ::Object.send(:remove_const, :PowerAssert)
+  end
 end
 
 module Test
